@@ -1,10 +1,10 @@
 import re
-from typing import Optional
 import string
+from typing import Optional
 
-from robot.api.parsing import ModelTransformer, Token, KeywordCall
+from robot.api.parsing import KeywordCall, ModelTransformer, Token
 
-from robotidy.decorators import check_start_end_line
+from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
 from robotidy.exceptions import InvalidParameterValueError
 
 
@@ -16,31 +16,37 @@ class RenameKeywords(ModelTransformer):
 
     You can keep underscores if you set remove_underscores to False:
 
-        robotidy --transform RenameKeywords -c RenameKeywords:remove_underscores=False .
+    ```
+    robotidy --transform RenameKeywords -c RenameKeywords:remove_underscores=False .
+    ```
 
     It is also possible to configure `replace_pattern` parameter to find and replace regex pattern. Use `replace_to`
     to set replacement value. This configuration (underscores are used instead of spaces):
 
-        robotidy --transform RenameKeywords -c RenameKeywords:replace_pattern=^(?i)rename\s?me$:replace_to=New_Shining_Name .
+    ```
+    robotidy --transform RenameKeywords -c RenameKeywords:replace_pattern=^(?i)rename\s?me$:replace_to=New_Shining_Name .
+    ```
 
     will transform following code:
 
-        *** Keywords ***
-        rename Me
-           Keyword Call
+    ```robotframework
+    *** Keywords ***
+    rename Me
+       Keyword Call
+    ```
 
     To:
 
-        *** Keywords ***
-        New Shining Name
-            Keyword Call
+    ```robotframework
+    *** Keywords ***
+    New Shining Name
+        Keyword Call
+    ```
 
     Use `ignore_library = True` parameter to control if the library name part (Library.Keyword) of keyword call
     should be renamed.
 
     Supports global formatting params: ``--startline`` and ``--endline``.
-
-    See https://robotidy.readthedocs.io/en/latest/transformers/RenameKeywords.html for more examples.
     """
 
     ENABLED = False
@@ -65,7 +71,11 @@ class RenameKeywords(ModelTransformer):
             )
         self.replace_to = "" if replace_to is None else replace_to
 
-    @check_start_end_line
+    @skip_section_if_disabled
+    def visit_Section(self, node):  # noqa
+        return self.generic_visit(node)
+
+    @skip_if_disabled
     def rename_node(self, node, type_of_name):
         token = node.get_token(type_of_name)
         if not token or not token.value:
